@@ -89,7 +89,6 @@ expect <- function(ok, failure_message,
 #' @param message Message describing test failure
 #' @param srcref Optional `srcref` giving location of test.
 #' @inheritParams expect
-#' @keywords internal
 #' @export
 expectation <- function(type, message, srcref = NULL, trace = NULL) {
   new_expectation(type, message, srcref = srcref, trace = trace)
@@ -249,16 +248,12 @@ single_letter_summary <- function(x) {
   )
 }
 
-expectation_location <- function(x) {
-  if (!inherits(x$srcref, "srcref")) {
-    "???"
-  } else {
-    srcfile <- attr(x$srcref, "srcfile")
-    filename <- srcfile$filename
-    if (identical(filename, "")) {
-      paste0("Line ", x$srcref[1])
-    } else {
-      cli::format_inline("{.file {filename}:{x$srcref[1]}:{x$srcref[2]}}")
-    }
+expectation_location <- function(x, prefix = "", suffix = "") {
+  srcref <- x$srcref
+  if (!inherits(srcref, "srcref")) {
+    return("")
   }
+
+  filename <- attr(srcref, "srcfile")$filename
+  cli::format_inline("{prefix}{.file {filename}:{srcref[1]}:{srcref[2]}}{suffix}")
 }
