@@ -15,6 +15,12 @@ test_that("truncates long differences", {
   expect_match(cnd$message, "...")
 })
 
+test_that("can compare data frames", {
+  # this isn't really a legit use case but one package does it
+  df <- data.frame(x = 1:10, y = 10:1)
+  expect_success(expect_setequal(unname(df), unname(df)))
+})
+
 test_that("warns if both inputs are named", {
   expect_warning(expect_setequal(c(a = 1), c(b = 1)), "ignores names")
 })
@@ -23,14 +29,19 @@ test_that("error for non-vectors", {
   expect_error(expect_setequal(sum, sum), "be vectors")
 })
 
-test_that("useful message on faillure", {
-  x1 <- c("a", "b")
-  x2 <- c("b", "c")
-  y1 <- 1:3
-  y2 <- 2:50
+test_that("useful message on failure", {
+  expect_snapshot_failure(expect_setequal("actual", "expected"))
 
-  expect_snapshot_failure(expect_setequal(x1, x2))
-  expect_snapshot_failure(expect_setequal(y1, y2))
+  expect_snapshot_failure(expect_setequal(1:2, 2))
+  expect_snapshot_failure(expect_setequal(2, 2:3))
+  expect_snapshot_failure(expect_setequal(1:2, 2:3))
+
+  # doesn't repeat values
+  expect_snapshot_failure(expect_setequal(c("a", "a"), c("b", "b", "b")))
+})
+
+test_that("truncates long vectors", {
+  expect_snapshot_failure(expect_setequal(1:2, 1:50))
 })
 
 # mapequal ----------------------------------------------------------------
@@ -112,4 +123,3 @@ test_that("expect_in() gives useful message on failure", {
   expect_snapshot_failure(expect_in(x1, x2))
   expect_snapshot_failure(expect_in(x1, x3))
 })
-
